package com.example.aitest.controller.websocket;


import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.CrossOrigin;
import javax.websocket.*;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

@CrossOrigin
@Slf4j
@ServerEndpoint(value = "/danger/get")
@Component
public class WebSocketServer {

    private static final List<Session> sessionList = new CopyOnWriteArrayList<>();

    @OnOpen
    public void onOpen(Session session) throws IOException {
        sessionList.add(session);
        log.info("有新用户加入聊天，当前在线人数为{}", sessionList.size());
    }

    @OnMessage
    public void onMessage(String message) throws IOException {
        log.info("webMessage{}",message);
        sendAllSession(message);
    }

    @OnError
    public void onError(Throwable error) {
        log.error("发生错误");
        error.printStackTrace();
    }

    @OnClose
    public void onClose(Session session) {
        log.info("有一个用户断开连接了");
        sessionList.remove(session);
    }

    /*
     * 发消息给客户端
     * */
    public static void sendAllSession(String message){

        try {
            for (Session session : sessionList) {
                log.info("给客户端发送消息{}", session);
                session.getBasicRemote().sendText(message);
            }
        } catch (Exception e) {
            log.error("消息发送失败", e);
        }

    }


}
