package com.example.aitest.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.example.aitest.controller.websocket.WebSocketServer;
import com.example.aitest.service.ApiService;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;

@Service
public class ApiServiceImpl implements ApiService {
    private static final String API_SECRET_KEY = "sk-zk23dcb27bb18e67d9ea0d749ed62f8088a667936c4c0682";
    private static final String BASE_URL = "https://api.zhizengzeng.com/v1/chat/completions";
    @Resource
    RedisTemplate<String, Object> redisTemplate;

    @Override
    public JSONObject processImage(File imageFile) {
        CloseableHttpClient httpClient = HttpClients.createDefault();
        System.out.println("进入processImage");
        // 构建请求体
        JSONObject content = new JSONObject();
        content.put("type", "text");
        content.put("text", "你现在是一个带有警报系统的人类安全分析监控，只分析我上传的图片中的人物的动作、神态、在做什么？是否有生命危险，判断后给出警报等级：一级警报、二级警报、三级警报。在你的回答的最后，需要有一个括号，括号中包含判断出的警报等级");

        JSONObject imageContent = new JSONObject();
        imageContent.put("type", "image_url");
        JSONObject imageUrl = new JSONObject();
        imageUrl.put("url", "http://49.233.248.140:8081/images/" + imageFile.getName());
        imageContent.put("image_url", imageUrl);

        JSONObject message = new JSONObject();
        message.put("role", "user");
        message.put("content", new JSONObject[]{content, imageContent});

        JSONObject requestBodyJson = new JSONObject();
        requestBodyJson.put("model", "gpt-4o");
        requestBodyJson.put("messages", new JSONObject[]{message});
        requestBodyJson.put("max_tokens", 300);

        StringEntity requestEntity = new StringEntity(requestBodyJson.toJSONString(), ContentType.APPLICATION_JSON);

        HttpPost httpPost = new HttpPost(BASE_URL);
        httpPost.setHeader("Authorization", "Bearer " + API_SECRET_KEY);
        httpPost.setHeader("Content-Type", "application/json");
        httpPost.setEntity(requestEntity);
        try (CloseableHttpResponse response = httpClient.execute(httpPost)) {
//            if (response.getCode() != 200) {
//                throw new HttpResponseException(response.getCode(), "Unexpected response status");
//            }
            // Parse the JSON response
            String responseBody = new String(response.getEntity().getContent().readAllBytes());
            JSONObject jsonResponse = JSON.parseObject(responseBody);
            jsonResponse.put("imgUrl", imageFile.getName());
            System.out.println(jsonResponse.toJSONString());
            if (jsonResponse.toJSONString().contains("一级警报")) {
                WebSocketServer.sendAllSession("一级");
                jsonResponse.put("grade", "一级");
            } else if (jsonResponse.toJSONString().contains("二级警报")) {
                WebSocketServer.sendAllSession("二级");
                jsonResponse.put("grade", "二级");
            } else {
                WebSocketServer.sendAllSession("三级");
                jsonResponse.put("grade", "三级");
            }
            return jsonResponse;
        } catch (IOException e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        }
    }

    @Override
    public ResponseEntity<String> timeChange(String time) {
        try {
            redisTemplate.opsForValue().set("CollectionTime", time);
        } catch (Exception e) {
            return ResponseEntity.badRequest().body("error");
        }
        return ResponseEntity.ok("success");
    }

    @Override
    public ResponseEntity<String> timeGet() {
        Object collectionTime = redisTemplate.opsForValue().get("CollectionTime");
        if (collectionTime == null) {
            return ResponseEntity.badRequest().body("error");
        }
        return ResponseEntity.ok(collectionTime.toString());
    }
}
